@@ -12,7 +12,7 @@ from .folder import MailBoxFolderManager
 from .utils import clean_uids, check_command_status, chunks, encode_folder, clean_flags, decode_value
 from .errors import MailboxStarttlsError, MailboxLoginError, MailboxLogoutError, MailboxNumbersError, \
     MailboxFetchError, MailboxExpungeError, MailboxDeleteError, MailboxCopyError, MailboxFlagError, \
-    MailboxAppendError, MailboxUidsError
+    MailboxAppendError, MailboxUidsError, MailboxFolderSelectError
 from .consts import ImapLoginConfig
 
 # Maximal line length when calling readline(). This is to prevent reading arbitrary length lines.
@@ -144,10 +144,12 @@ class BaseMailBox:
 
         """
         encoded_criteria = criteria if type(criteria) is bytes else str(criteria).encode(charset)
-        self.box.select(mailbox=mailbox, readonly=False)
+        select_result = self.box.select(mailbox=mailbox, readonly=False)
+        check_command_status(select_result, MailboxFolderSelectError)
         search_result = self.box.search(charset, encoded_criteria)
         check_command_status(search_result, MailboxNumbersError)
         for mail_id in search_result[1][0].decode().split():
+            print("select_search mail_id: {}".format(mail_id))
             fetch_result = self.box.fetch(
                 mail_id, "(RFC822)"
             )  ## Fetch mail data.
@@ -327,7 +329,8 @@ class MailBox(BaseMailBox):
         result = self.box.authenticate('XOAUTH2', lambda x: auth_string)  # noqa
         check_command_status(result, MailboxLoginError)
         self.folder = self.folder_manager_class(self)
-        self.folder.set(initial_folder)
+        if initial_folder:
+            self.folder.set(initial_folder)
         self.login_result = result
         return self
 
